@@ -253,115 +253,65 @@ PREPROCESSED_DF = pd.DataFrame(
             87126: 12.25,
             87127: 12.25,
         },
-        "BS_gradient": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
-        },
-        "BS_log": {
-            12535: 1.1222158782728267,
-            12536: 1.1222158782728267,
-            30344: 1.2671717284030137,
-            30345: 1.2671717284030137,
-            69538: 1.1222158782728267,
-            69539: 1.1222158782728267,
-            87126: 1.1222158782728267,
-            87127: 1.1222158782728267,
-        },
-        "BS_window_max": {
-            12535: 12.25,
-            12536: 12.25,
-            30344: 17.5,
-            30345: 17.5,
-            69538: 12.25,
-            69539: 12.25,
-            87126: 12.25,
-            87127: 12.25,
-        },
-        "BS_window_mean": {
-            12535: 12.25,
-            12536: 12.25,
-            30344: 17.5,
-            30345: 17.5,
-            69538: 12.25,
-            69539: 12.25,
-            87126: 12.25,
-            87127: 12.25,
-        },
-        "BS_window_min": {
-            12535: 12.25,
-            12536: 12.25,
-            30344: 17.5,
-            30345: 17.5,
-            69538: 12.25,
-            69539: 12.25,
-            87126: 12.25,
-            87127: 12.25,
-        },
         "DENC": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DENC_gradient": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DENC_log": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DENC_window_max": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DENC_window_mean": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DENC_window_min": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
         "DEPTH": {
             12535: 2100.4256,
@@ -373,125 +323,75 @@ PREPROCESSED_DF = pd.DataFrame(
             87126: 1450.086,
             87127: 1450.2384,
         },
-        "GR": {
-            12535: 55.46915,
-            12536: 60.19225,
-            30344: 60.19224999999982,
-            30345: 55.46915000000019,
-            69538: 55.46915,
-            69539: 60.19225,
-            87126: 55.469149999999985,
-            87127: 60.192250000000016,
-        },
         "GR_gradient": {
-            12535: 4.723100000000002,
-            12536: 4.723100000000002,
-            30344: -4.723099999999626,
-            30345: -4.723099999999626,
+            12535: 0.7099999999999937,
+            12536: 0.7099999999999937,
+            30344: -0.17419999999999902,
+            30345: -0.17419999999999902,
             69538: 4.723100000000002,
             69539: 4.723100000000002,
-            87126: 4.723100000000031,
-            87127: 4.723100000000031,
+            87126: 1.4396100000000018,
+            87127: 1.4396100000000018,
         },
         "GR_log": {
-            12535: 1.751811250582852,
-            12536: 1.7866964222213135,
-            30344: 1.7866964222213122,
-            30345: 1.7518112505828534,
+            12535: 2.00337435401975,
+            12536: 2.006423252507643,
+            30344: 2.038250476866334,
+            30345: 2.037557165061478,
             69538: 1.751811250582852,
             69539: 1.7866964222213135,
-            87126: 1.7518112505828518,
-            87127: 1.7866964222213138,
+            87126: 1.759771911836876,
+            87127: 1.7705087834084305,
         },
         "GR_window_max": {
-            12535: 55.46915,
-            12536: 60.19225,
-            30344: 60.19224999999982,
-            30345: 60.19224999999982,
+            12535: 99.78,
+            12536: 100.49,
+            30344: 108.207,
+            30345: 108.207,
             69538: 55.46915,
             69539: 60.19225,
-            87126: 55.469149999999985,
-            87127: 60.192250000000016,
+            87126: 56.51378,
+            87127: 57.95339,
         },
         "GR_window_mean": {
-            12535: 55.46915,
-            12536: 57.8307,
-            30344: 60.19224999999982,
-            30345: 57.83070000000001,
+            12535: 99.78,
+            12536: 100.13499999999999,
+            30344: 108.207,
+            30345: 108.1199,
             69538: 55.46915,
             69539: 57.8307,
-            87126: 55.469149999999985,
-            87127: 57.8307,
+            87126: 56.51378,
+            87127: 57.233585,
         },
         "GR_window_min": {
-            12535: 55.46915,
-            12536: 55.46915,
-            30344: 60.19224999999982,
-            30345: 55.46915000000019,
+            12535: 99.78,
+            12536: 99.78,
+            30344: 108.207,
+            30345: 108.0328,
             69538: 55.46915,
             69539: 55.46915,
-            87126: 55.469149999999985,
-            87127: 55.469149999999985,
+            87126: 56.51378,
+            87127: 56.51378,
         },
         "NEU": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+            12535: nan,
+            12536: nan,
+            30344: nan,
+            30345: nan,
+            69538: nan,
+            69539: nan,
+            87126: nan,
+            87127: nan,
         },
-        "NEU_gradient": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
-        },
-        "NEU_log": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
-        },
-        "NEU_window_max": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
-        },
-        "NEU_window_mean": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
-        },
-        "NEU_window_min": {
-            12535: 0.0,
-            12536: 0.0,
-            30344: 0.0,
-            30345: 0.0,
-            69538: 0.0,
-            69539: 0.0,
-            87126: 0.0,
-            87127: 0.0,
+        "RAVG": {
+            12535: 0.735,
+            12536: 0.70500005,
+            30344: 0.4647593,
+            30345: 0.50095115,
+            69538: 0.6184339999999999,
+            69539: 0.61022,
+            87126: 0.7484,
+            87127: 0.7484,
         },
         "RDEP": {
             12535: 0.77,
@@ -514,14 +414,14 @@ PREPROCESSED_DF = pd.DataFrame(
             87127: 0.0,
         },
         "RDEP_log": {
-            12535: 0.24797326636180664,
-            12536: 0.2380461031287954,
-            30344: 0.16481287497678626,
-            30345: 0.17613103860834783,
-            69538: 0.18342018322319556,
-            69539: 0.19015233954633776,
-            87126: 0.24264079781761497,
-            87127: 0.24264079781761497,
+            12535: 1.0,
+            12536: 0.8806263045702858,
+            30344: 0.0,
+            30345: 0.13610041322629352,
+            69538: 0.22375205234737505,
+            69539: 0.30470593208530605,
+            87126: 0.9358773034207699,
+            87127: 0.9358773034207699,
         },
         "RDEP_window_max": {
             12535: 0.77,
@@ -718,7 +618,7 @@ FORMATION_TOPS_MAPPER = {
             "Permian",
         ],
         "group_levels": [164.0, 777.0, 1768.0, 2069.0, 2072.0, 2173.0, 2488.0, 2513.0],
-    },
+    }
 }
 
 FORMATION_DF = pd.DataFrame(
@@ -740,36 +640,36 @@ FORMATION_DF = pd.DataFrame(
             662138: 2368.1436,
         },
         "FORMATION": {
-            650372: "Utsira Formation",
-            651258: "UNKNOWN",
-            651698: "Skade Formation",
-            654933: "UNKNOWN",
-            656475: "Grid Formation",
-            658201: "Balder Formation",
-            658496: "Sele Formation",
-            658745: "Lista Formation",
-            658778: "Heimdal Formation",
-            659959: "Ty Formation",
-            660176: "Tor Formation",
-            660195: "UNKNOWN",
-            660858: "Skagerrak Formation",
-            662138: "Smith Bank Formation",
+            650372: "UTSIRA FM",
+            651258: "UNKNOWN FM",
+            651698: "SKADE FM",
+            654933: "UNKNOWN FM",
+            656475: "GRID FM",
+            658201: "BALDER FM",
+            658496: "SELE FM",
+            658745: "LISTA FM",
+            658778: "HEIMDAL FM",
+            659959: "TY FM",
+            660176: "TOR FM",
+            660195: "UNKNOWN FM",
+            660858: "SKAGERRAK FM",
+            662138: "SMITH BANK FM",
         },
         "GROUP": {
-            650372: "Nordland Group",
-            651258: "Nordland Group",
-            651698: "Hordaland Group",
-            654933: "Hordaland Group",
-            656475: "Hordaland Group",
-            658201: "Rogaland Group",
-            658496: "Rogaland Group",
-            658745: "Rogaland Group",
-            658778: "Rogaland Group",
-            659959: "Rogaland Group",
-            660176: "Shetland Group",
-            660195: "Statfjord Group",
-            660858: "UNKNOWN",
-            662138: "UNKNOWN",
+            650372: "NORDLAND GP",
+            651258: "NORDLAND GP",
+            651698: "HORDALAND GP",
+            654933: "HORDALAND GP",
+            656475: "HORDALAND GP",
+            658201: "ROGALAND GP",
+            658496: "ROGALAND GP",
+            658745: "ROGALAND GP",
+            658778: "ROGALAND GP",
+            659959: "ROGALAND GP",
+            660176: "SHETLAND GP",
+            660195: "STATFJORD GP",
+            660858: "UNKNOWN GP",
+            662138: "UNKNOWN GP",
         },
         "well_name": {
             650372: "25/10-10",
@@ -1123,8 +1023,6 @@ VERTICAL_DF = pd.DataFrame(
             1142979: 1091.789371459583,
             1142980: 1091.9413367266493,
             1142981: 1092.093301993716,
-            1142982: nan,
-            1142983: nan,
         },
         "TVDSS": {
             1142969: 1050.2697187889175,
@@ -1140,8 +1038,6 @@ VERTICAL_DF = pd.DataFrame(
             1142979: 1051.789371459583,
             1142980: 1051.9413367266493,
             1142981: 1052.093301993716,
-            1142982: nan,
-            1142983: nan,
         },
         "TVDBML": {
             1142969: 926.7697187889175,
@@ -1157,8 +1053,6 @@ VERTICAL_DF = pd.DataFrame(
             1142979: 928.289371459583,
             1142980: 928.4413367266494,
             1142981: 928.593301993716,
-            1142982: nan,
-            1142983: nan,
         },
         "well_name": {
             1142969: "25/10-10",
@@ -1174,8 +1068,6 @@ VERTICAL_DF = pd.DataFrame(
             1142979: "25/10-10",
             1142980: "25/10-10",
             1142981: "25/10-10",
-            1142982: "25/10-10",
-            1142983: "25/10-10",
         },
     }
 )
